@@ -5,5 +5,7 @@
 
 from .colors import *
 from .plot import *
+from .style import *
+from .text import *
 
-__version__ = '0.3.0'
+__version__ = '0.4.2'
